# Configuration API

::: wd.di.config.IConfiguration
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.config.Options
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.config.OptionsBuilder
    handler: python
    options:
      show_root_heading: true
      show_source: false
